Built-in auth login, auth status, and auth logout command helpers.
Structs
- Auth
Login Result - Data rendered after a successful
auth login. - Auth
Status Entry - Data rendered by
auth status.
Functions
- auth_
command_ group - Builds the built-in runtime
authcommand group. - login_
and_ build - Runs dispatcher login and converts the credential to renderable output.
- login_
and_ build_ with_ scopes - Like
login_and_build, but requestsadditional_scopeson top of the provider’s defaults (used byauth login --scope). - logout_
result - Runs dispatcher logout and builds the renderable result.
- status_
result - Builds the JSON value rendered by
auth status. - to_
status_ entry - Converts an optional credential into an auth status row.