pub fn build_root_long(
intro: &str,
entries: &[ModuleHelpEntry],
has_guide: bool,
) -> StringExpand description
Builds the root long help text from module categories and built-in command hints.
pub fn build_root_long(
intro: &str,
entries: &[ModuleHelpEntry],
has_guide: bool,
) -> StringBuilds the root long help text from module categories and built-in command hints.