pub fn render_next_actions_human(actions: &[NextAction]) -> StringExpand description
Builds a “Next actions” section appended to bare-root human help. Returns an empty string when there are no actions so the help output is unchanged.
pub fn render_next_actions_human(actions: &[NextAction]) -> StringBuilds a “Next actions” section appended to bare-root human help. Returns an empty string when there are no actions so the help output is unchanged.