pub type ResolveMeta = Arc<dyn Fn(&str, CommandMeta) -> CommandMeta + Send + Sync>;Expand description
Hook used to adjust command metadata globally before middleware executes.
Aliased Type
pub struct ResolveMeta { /* private fields */ }pub type ResolveMeta = Arc<dyn Fn(&str, CommandMeta) -> CommandMeta + Send + Sync>;Hook used to adjust command metadata globally before middleware executes.
pub struct ResolveMeta { /* private fields */ }