pub fn lookup_global_human_view_func(
schema_id: &str,
) -> Option<HumanViewRenderer>Expand description
Looks up a global custom renderer for a schema id.
pub fn lookup_global_human_view_func(
schema_id: &str,
) -> Option<HumanViewRenderer>Looks up a global custom renderer for a schema id.