render_human_with_registry_for_schema

Function render_human_with_registry_for_schema 

pub fn render_human_with_registry_for_schema(
    envelope: &Envelope,
    registry: &HumanViewRegistry,
    schema_id: &str,
) -> String
Renders an envelope using registry entries for a specific schema id.

Shows every column of the registered view. Use render_human_with_registry_selected to narrow the columns to a field selection.