prompt_select

Function prompt_select 

pub fn prompt_select(message: &str, options: &[String]) -> Result<usize>
Prompt the user to select one option from a list.

Returns the index of the selected option.

Errors

Returns CliCoreError if the prompt is cancelled or a terminal error occurs.