prompt_text

Function prompt_text 

pub fn prompt_text(message: &str, default: Option<&str>) -> Result<String>
Prompt the user for a free-text string input.

Returns the trimmed user input, or an error if the user cancelled.

Errors

Returns CliCoreError if the prompt is cancelled or a terminal error occurs.