Module commands

Module commands 

Built-in auth login, auth status, and auth logout command helpers.

Structs

AuthLoginResult
Data rendered after a successful auth login.
AuthStatusEntry
Data rendered by auth status.

Functions

auth_command_group
Builds the built-in runtime auth command group.
login_and_build
Runs dispatcher login and converts the credential to renderable output.
logout_result
Runs dispatcher logout and builds the renderable result.
status_result
Builds the JSON value rendered by auth status.
to_status_entry
Converts an optional credential into an auth status row.