pub struct CommandResult {
pub data: Value,
pub metadata: CommandResultMetadata,
}Expand description
Data returned by a command handler.
Command handlers should return renderable data and keep output metadata on
CommandSpec. The metadata field is reserved for future command-result
extensions that are not known when the command is registered.
Fields
data: ValueJSON data rendered by the configured output formatter.
metadata: CommandResultMetadataOptional command-result extension metadata.
Implementations
Sourceimpl CommandResult
impl CommandResult
Sourcepub fn with_next_actions(self, actions: Vec<NextAction>) -> Self
pub fn with_next_actions(self, actions: Vec<NextAction>) -> Self
Attaches suggested follow-up actions to this result.