GroupSpec

Struct GroupSpec 

pub struct GroupSpec {
    pub name: String,
    pub short: String,
    pub long: Option<String>,
    pub aliases: Vec<String>,
    pub hidden: bool,
    pub commands: Vec<CommandSpec>,
    pub groups: Vec<GroupSpec>,
}
Declarative command group metadata.

Groups are noun-based containers. They do not run business logic directly; when invoked bare, the CLI renders group help.

Fields

name: String

Group command name.

short: String

One-line group description.

long: Option<String>

Optional long help text.

aliases: Vec<String>

Alternate group names accepted by the parser.

hidden: bool

Whether the group runs but is hidden from discovery output.

commands: Vec<CommandSpec>

Declarative child commands used for static tree construction.

groups: Vec<GroupSpec>

Declarative nested groups used for static tree construction.

Implementations

Source

impl GroupSpec

pub fn new(name: impl Into<String>, short: impl Into<String>) -> Self

Creates a command group with the required name and one-line help.

pub fn with_long(self, long: impl Into<String>) -> Self

Sets expanded group help.

pub fn with_alias(self, alias: impl Into<String>) -> Self

Adds one group alias.

pub fn hidden(self, hidden: bool) -> Self

Hides or shows this group in discovery output.

pub fn with_command(self, command: CommandSpec) -> Self

Adds one declarative child command.

pub fn with_group(self, group: GroupSpec) -> Self

Adds one declarative nested group.

pub fn clap_command(&self) -> Command

Builds the clap command for parser registration.