config_file_path

Function config_file_path 

pub fn config_file_path(app_id: &str) -> Option<PathBuf>
Returns the path to the engine config file for app_id, if a base config directory can be resolved and app_id is a safe single path component.