pub struct GlobalFlags {Show 14 fields
pub output_format: String,
pub verbose: String,
pub dry_run: bool,
pub fields: String,
pub filter: String,
pub expr: String,
pub limit: i64,
pub offset: i64,
pub schema: bool,
pub reason: String,
pub timeout: String,
pub debug: String,
pub search: String,
pub credential_store: Option<CredentialStore>,
}Expand description
Parsed framework-global flags.
Applications can add their own global flags, but these are the built-in controls understood by middleware and the output pipeline.
Fields
output_format: StringOutput format: json, human, or toon.
verbose: StringMetadata verbosity selector.
dry_run: boolWhether mutating commands should short-circuit.
fields: StringField projection.
filter: StringJMESPath per-item filter.
expr: StringJMESPath whole-result expression.
limit: i64Client-side page size.
offset: i64Client-side page offset.
schema: boolWhether schema rendering was requested.
reason: StringUser-provided command reason.
timeout: StringRaw timeout string.
debug: StringDebug selector.
search: StringSearch query.
credential_store: Option<CredentialStore>Credential storage override from --credential-store, if supplied.