pub fn render_human_with_registry_for_schema(
envelope: &Envelope,
registry: &HumanViewRegistry,
schema_id: &str,
) -> StringExpand description
Renders an envelope using registry entries for a specific schema id.
pub fn render_human_with_registry_for_schema(
envelope: &Envelope,
registry: &HumanViewRegistry,
schema_id: &str,
) -> StringRenders an envelope using registry entries for a specific schema id.